# Generated by Django 4.2.11 on 2024-06-02 17:59

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('loans', '0006_loan_penalty_charged_loan_penalty_charged_date_and_more'),
        ('operations', '0009_chargedpenalty'),
    ]

    operations = [
        migrations.CreateModel(
            name='PayPenalty',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Создана')),
                ('amount', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Сумма')),
                ('is_export', models.BooleanField(default=True, help_text='Без галочки: не отправлять данные в 1С', verbose_name='Выгружать')),
                ('comment', models.CharField(blank=True, max_length=1024, verbose_name='Комментарий')),
                ('loan', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='loans.loan', verbose_name='Займ')),
                ('pay', models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='operations.pay', verbose_name='Платеж')),
            ],
            options={
                'verbose_name': 'Погашенные пени',
                'verbose_name_plural': 'Погашенные пени',
            },
        ),
    ]
