# Generated by Django 4.2.11 on 2024-05-28 11:38

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('loans', '0005_delete_schedule'),
        ('operations', '0005_alter_bodyissue_amount'),
    ]

    operations = [
        migrations.AlterField(
            model_name='payinterests',
            name='is_export',
            field=models.BooleanField(default=True, help_text='Без галочки: не отправлять данные в 1С', verbose_name='Выгружать'),
        ),
        migrations.CreateModel(
            name='AutoPay',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Создана')),
                ('amount', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Сумма')),
                ('bank_card_id', models.PositiveIntegerField()),
                ('fee', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Комиссия')),
                ('penalty', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Платеж по пени')),
                ('interests', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Платеж по процентам')),
                ('body', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Платеж по телу')),
                ('payment_id', models.CharField(help_text='Номер в CloudPayments', max_length=64, verbose_name='TransactionId')),
                ('comment', models.CharField(blank=True, max_length=1024)),
                ('loan', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='loans.loan', verbose_name='Займ')),
            ],
            options={
                'verbose_name': 'Автоплатеж',
                'verbose_name_plural': 'Автоплатеж',
            },
        ),
    ]
