# Generated by Django 4.2.11 on 2024-04-19 18:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('operations', '0002_alter_bodyissue_payment_id_alter_pay_payment_id'),
    ]

    operations = [
        migrations.AddField(
            model_name='pay',
            name='fee',
            field=models.DecimalField(decimal_places=0, default=0, max_digits=7, verbose_name='Комиссия'),
            preserve_default=False,
        ),
    ]
