# Generated by Django 4.2.11 on 2024-04-19 16:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('operations', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bodyissue',
            name='payment_id',
            field=models.CharField(default='', help_text='Если заполнено, значит деньги отправлены', max_length=64, verbose_name='TransactionId'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='pay',
            name='payment_id',
            field=models.CharField(default='', help_text='Номер в CloudPayments', max_length=64, verbose_name='TransactionId'),
            preserve_default=False,
        ),
    ]
