# Generated by Django 4.2.11 on 2024-05-28 11:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('operations', '0006_alter_payinterests_is_export_autopay'),
    ]

    operations = [
        migrations.AddField(
            model_name='pay',
            name='is_auto',
            field=models.BooleanField(default=False, verbose_name='Автоплатеж'),
        ),
        migrations.DeleteModel(
            name='AutoPay',
        ),
    ]
