# Generated by Django 4.2.11 on 2024-04-21 07:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('operations', '0003_pay_fee'),
    ]

    operations = [
        migrations.AlterField(
            model_name='chargedinterests',
            name='amount',
            field=models.DecimalField(decimal_places=0, max_digits=7, null=True, verbose_name='Сумма'),
        ),
    ]
